@@ -30,23 +30,23 @@ const globalConfig = {
 // Create a separate directory for each test so that the tests
 // can run in parallel
 
-test.cb.beforeEach(t => {
+test.beforeEach.cb(t => {
   createTestDirectory(outputDir, t.title, (err, directory) => {
     if (err) return t.end(err);
     t.context.directory = directory;
     t.end();
   });
 });
-test.cb.beforeEach(t => {
+test.beforeEach.cb(t => {
   createTestDirectory(cacheDir, t.title, (err, directory) => {
     if (err) return t.end(err);
     t.context.cacheDirectory = directory;
     t.end();
   });
 });
-test.cb.beforeEach(t => rimraf(defaultCacheDir, t.end));
-test.cb.afterEach(t => rimraf(t.context.directory, t.end));
-test.cb.afterEach(t => rimraf(t.context.cacheDirectory, t.end));
+test.beforeEach.cb(t => rimraf(defaultCacheDir, t.end));
+test.afterEach.cb(t => rimraf(t.context.directory, t.end));
+test.afterEach.cb(t => rimraf(t.context.cacheDirectory, t.end));
 
 test.cb("should output files to cache directory", t => {
   const config = Object.assign({}, globalConfig, {
@@ -61,7 +61,7 @@ test.cb("should output files to cache directory", t => {
           exclude: /node_modules/,
           options: {
             cacheDirectory: t.context.cacheDirectory,
-            presets: ["env"],
+            presets: ["@babel/preset-env"],
           },
         },
       ],
@@ -81,7 +81,7 @@ test.cb("should output files to cache directory", t => {
   });
 });
 
-test.cb.serial(
+test.serial.cb(
   "should output json.gz files to standard cache dir by default",
   t => {
     const config = Object.assign({}, globalConfig, {
@@ -96,7 +96,7 @@ test.cb.serial(
             exclude: /node_modules/,
             options: {
               cacheDirectory: true,
-              presets: ["env"],
+              presets: ["@babel/preset-env"],
             },
           },
         ],
@@ -119,7 +119,44 @@ test.cb.serial(
   },
 );
 
-test.cb.serial(
+test.serial.cb(
+  "should output non-compressed files to standard cache dir when cacheCompression is set to false",
+  t => {
+    const config = Object.assign({}, globalConfig, {
+      output: {
+        path: t.context.directory,
+      },
+      module: {
+        rules: [
+          {
+            test: /\.jsx?/,
+            loader: babelLoader,
+            exclude: /node_modules/,
+            options: {
+              cacheDirectory: true,
+              cacheCompression: false,
+              presets: ["@babel/preset-env"],
+            },
+          },
+        ],
+      },
+    });
+
+    webpack(config, err => {
+      t.is(err, null);
+
+      fs.readdir(defaultCacheDir, (err, files) => {
+        files = files.filter(file => /\b[0-9a-f]{5,40}\b/.test(file));
+
+        t.is(err, null);
+        t.true(files.length > 0);
+        t.end();
+      });
+    });
+  },
+);
+
+test.serial.cb(
   "should output files to standard cache dir if set to true in query",
   t => {
     const config = Object.assign({}, globalConfig, {
@@ -130,7 +167,7 @@ test.cb.serial(
         rules: [
           {
             test: /\.jsx?/,
-            loader: `${babelLoader}?cacheDirectory=true&presets[]=env`,
+            loader: `${babelLoader}?cacheDirectory=true&presets[]=@babel/preset-env`,
             exclude: /node_modules/,
           },
         ],
@@ -146,6 +183,7 @@ test.cb.serial(
         files = files.filter(file => /\b[0-9a-f]{5,40}\.json\.gz\b/.test(file));
 
         t.is(err, null);
+
         t.true(files.length > 0);
         t.end();
       });
@@ -153,7 +191,7 @@ test.cb.serial(
   },
 );
 
-test.cb.skip("should read from cache directory if cached file exists", t => {
+test.cb("should read from cache directory if cached file exists", t => {
   const config = Object.assign({}, globalConfig, {
     output: {
       path: t.context.directory,
@@ -166,7 +204,7 @@ test.cb.skip("should read from cache directory if cached file exists", t => {
           exclude: /node_modules/,
           options: {
             cacheDirectory: t.context.cacheDirectory,
-            presets: ["env"],
+            presets: ["@babel/preset-env"],
           },
         },
       ],
@@ -204,7 +242,7 @@ test.cb("should have one file per module", t => {
           exclude: /node_modules/,
           options: {
             cacheDirectory: t.context.cacheDirectory,
-            presets: ["env"],
+            presets: ["@babel/preset-env"],
           },
         },
       ],
@@ -239,7 +277,7 @@ test.cb("should generate a new file if the identifier changes", t => {
             options: {
               cacheDirectory: t.context.cacheDirectory,
               cacheIdentifier: "a",
-              presets: ["env"],
+              presets: ["@babel/preset-env"],
             },
           },
         ],
@@ -258,7 +296,7 @@ test.cb("should generate a new file if the identifier changes", t => {
             options: {
               cacheDirectory: t.context.cacheDirectory,
               cacheIdentifier: "b",
-              presets: ["env"],
+              presets: ["@babel/preset-env"],
             },
           },
         ],
@@ -300,8 +338,9 @@ test.cb("should allow to specify the .babelrc file", t => {
             exclude: /node_modules/,
             options: {
               cacheDirectory: t.context.cacheDirectory,
-              babelrc: path.join(__dirname, "fixtures/babelrc"),
-              presets: ["env"],
+              extends: path.join(__dirname, "fixtures/babelrc"),
+              babelrc: false,
+              presets: ["@babel/preset-env"],
             },
           },
         ],
@@ -320,7 +359,7 @@ test.cb("should allow to specify the .babelrc file", t => {
             exclude: /node_modules/,
             options: {
               cacheDirectory: t.context.cacheDirectory,
-              presets: ["env"],
+              presets: ["@babel/preset-env"],
             },
           },
         ],
